"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.DEFAULT_TO = exports.DEFAULT_FROM = void 0;

var _date2 = _interopRequireDefault(require("../date"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Avoids pulling in something like moment.js just for this.
const DAY_REGEX = /^\d{4}-\d{2}-\d{2}$/;
/**
 * Strictly speaking, the ISO 8601 date format, though often abbreviated as "YYYY-MM-DD", allows for
 * an "extended" format containing a year with 5 to 6 digits preceded by a +/- sign:
 * https://tc39.es/ecma262/#sec-expanded-years.
 *
 * For convenience, this can be further narrowed to the range that would be expressible as
 * JavaScript `Dates`: approximately -271821-04-20 to +275760-09-13.
 *
 * However, supporting these formats breaks a number of assumptions in Good Eggs code and perhaps in
 * third-party libraries:
 * - sorting "date" strings alphanumerically results in a chronological sort
 * - extracting the "date" part of a `Date` as "YYYY-MM-DD" will always work
 * - etc.
 *
 * It doesn't seem worthwhile to require thousands of calls to `fake.day()` across repos that use
 * fake-eggs to pass in custom ranges to deal with this, nor to require thousands of calls to
 * moment.js's `.format('YYYY-MM-DD')` to be updated, since realistically we will never need to
 * manipulate dates over a thousand years ago nor dates eight thousand years from now, and
 * realistically our code will not run for eight thousand years. Therefore, we choose to support a
 * further narrowed range called "Complete date" by the W3C: https://www.w3.org/TR/NOTE-datetime.
 *
 * Finally, for convenience (e.g. generating a random day then adding or subtracting days), we clamp
 * the default range a bit further.
 */

const DEFAULT_FROM = '1001-01-01';
exports.DEFAULT_FROM = DEFAULT_FROM;
const DEFAULT_TO = '9999-01-01';
exports.DEFAULT_TO = DEFAULT_TO;

/**
 * Returns a randomly-selected ISO 8601 day string (`YYYY-MM-DD`), optionally between `from` and `to`.
 * TODO(serhalp) Consider dropping support for `from` and `to` being `Date`s as this is complex to
 * support and has many caveats.
 */
const createDayGenerator = chance => function () {
  let from = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_FROM;
  let to = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_TO;

  if (typeof from === 'string' && !DAY_REGEX.test(from)) {
    throw new TypeError('`from` must be a Date or a YYYY-MM-DD string');
  }

  if (typeof to === 'string' && !DAY_REGEX.test(to)) {
    throw new TypeError('`to` must be a Date or a YYYY-MM-DD string');
  }

  const _date = (0, _date2.default)(chance); // Note that much of what follows is dependent on the environment's time zone, which generally
  // should always be avoided, but since we're generating random data here, it seems OK, especially
  // given the alternative is to pull in a whole library like moment.js.


  const date = _date(new Date(from), new Date(to));

  const year = String(date.getFullYear()).padStart(4, '0');
  const month = String(date.getMonth() + 1).padStart(2, '0');
  const dayOfMonth = String(date.getDate()).padStart(2, '0');
  return `${year}-${month}-${dayOfMonth}`;
};

var _default = createDayGenerator;
exports.default = _default;
//# sourceMappingURL=index.js.map